/* -------------------------------------------------------------------
File "EleSta_v.pro"
Electrostatics - Electric scalar potential v formulation
-------------------------------------------------------------------
I N P U T
---------
Global Groups : (Extension _Ele is for Electric problem)
-------------
Domain_Ele Whole electric domain (not used)
DomainCC_Ele Nonconducting regions
DomainC_Ele Conducting regions (not used)
Function :
--------
epsr[] Relative permittivity
Constraint :
----------
ElectricScalarPotential Fixed electric scalar potential
(classical boundary condition)
Physical constants :
------------------ */

eps0 = 8.854187818e-12;
Group {
	DefineGroup[ Domain_Ele, DomainCC_Ele, DomainC_Ele, SkinDomainC ];
}

Function {
	DefineFunction[ epsr ];
}

FunctionSpace {
  { Name Hgrad_v_Ele; Type Form0;
    BasisFunction {
      { Name sn; NameOfCoef vn; Function BF_Node;
        Support DomainCC_Ele; Entity NodesOf[ All ]; }
    }
    
    Constraint {
      { NameOfCoef vn; EntityType NodesOf;
        NameOfConstraint ElectricScalarPotential; }
    }
  }

}

FunctionSpace {
  { Name Hgrad_v_floating; Type Form0;
    BasisFunction {
      { Name sn; NameOfCoef vn; Function BF_Node; Support DomainCC_Ele; Entity NodesOf[All, Not SkinDomainC]; }
      { Name sf; NameOfCoef vf; Function BF_GroupOfNodes; Support DomainCC_Ele; Entity GroupsOfNodesOf[SkinDomainC]; }
    }
    GlobalQuantity {
      { Name V; Type AliasOf; NameOfCoef vf; }
      { Name Q; Type AssociatedWith; NameOfCoef vf; }
    }

    Constraint {
      { NameOfCoef vn ;
        EntityType NodesOf ; NameOfConstraint ElectricScalarPotential ; }
      
      { NameOfCoef V ;
        EntityType GroupsOfNodesOf ; NameOfConstraint GlobalElectricPotential ; }
      { NameOfCoef Q ;
        EntityType GroupsOfNodesOf ; NameOfConstraint GlobalElectricCharge ; }
    }
  }

}

Formulation {
  { Name Electrostatics_v; Type FemEquation;
    Quantity {
      { Name v; Type Local; NameOfSpace Hgrad_v_Ele; }
    }
    
    Equation {
      Galerkin { [ epsr[] * Dof{d v} , {d v} ]; In DomainCC_Ele; Jacobian Vol; Integration GradGrad; }
    }
  }
}

Formulation {

    { Name Electrostatics_v_floating; Type FemEquation;
        Quantity {
            { Name v; Type Local;  NameOfSpace Hgrad_v_floating; }
            { Name V; Type Global; NameOfSpace Hgrad_v_floating [V]; }
            { Name Q; Type Global; NameOfSpace Hgrad_v_floating [Q]; }
         }
        Equation {
            Galerkin { [ epsr[] * Dof{d v} , {d v} ]; In DomainCC_Ele; Jacobian Vol; Integration GradGrad; }
            GlobalTerm { [ - Dof{Q}/eps0 , {V} ]; In SkinDomainC; }
        }
    }

}

Resolution {
  { Name EleSta_v;
    System {
      { Name Sys_Ele; NameOfFormulation Electrostatics_v; }
    }
    Operation {
      Generate[Sys_Ele]; Solve[Sys_Ele]; SaveSolution[Sys_Ele];
    }
  }

  { Name EleSta_vf;
    System {
      { Name Sys_Ele_f; NameOfFormulation Electrostatics_v_floating; }
    }
    Operation {
      Generate[Sys_Ele_f]; Solve[Sys_Ele_f]; SaveSolution[Sys_Ele_f];
    }
  }

}

PostProcessing {
  { Name EleSta_v; NameOfFormulation Electrostatics_v; NameOfSystem Sys_Ele;
    Quantity {
      { Name v;
        Value {
          Local { [ {v} ]; In DomainCC_Ele; Jacobian Vol; }
        }
      }
      { Name e;
        Value {
          Local { [ -{d v} ]; In DomainCC_Ele; Jacobian Vol; }
        }
      }
      { Name d;
        Value {
          Local { [ -eps0*epsr[] * {d v} ]; In DomainCC_Ele; Jacobian Vol; }
				}
      }
    }
  }
  
  { Name EleSta_vf; NameOfFormulation Electrostatics_v_floating; NameOfSystem Sys_Ele_f;
    Quantity {
      
      { Name v; Value { Local { [ {v} ]; In DomainCC_Ele; Jacobian Vol; } } }
      { Name e; Value { Local { [ -{Grad v} ]; In DomainCC_Ele;  Jacobian Vol; } } }
      { Name d; Value { Local { [ -eps0*epsr[] *{Grad v} ]; In DomainCC_Ele;  Jacobian Vol; } } }
      
      { Name Q; Value { Local { [ {Q} ]; In SkinDomainC; Jacobian Vol; } } }
      { Name V; Value { Local { [ {V} ]; In SkinDomainC; Jacobian Vol; } } }
    }
  }
}

